<img src="icon.png" align="right" height="110"/>

# Eisvogel

[![Build Status](https://travis-ci.org/Wandmalfarbe/pandoc-latex-template.svg?branch=master)](https://travis-ci.org/Wandmalfarbe/pandoc-latex-template)

A clean **pandoc LaTeX template** to convert your markdown files to PDF or LaTeX. It is designed for lecture notes and exercises with a focus on computer science. The template is compatible with pandoc 2.

## Preview

| A custom title page  | A basic example page |
| :------------------: | :------------------: |
| [![A custom title page](examples/custom-titlepage/custom-titlepage.png)](examples/custom-titlepage/custom-titlepage.pdf) | [![A basic example page](examples/basic-example/basic-example.png)](examples/basic-example/basic-example.pdf) |

## Installation

1.  Install pandoc from <http://pandoc.org/>. You also need to install [LaTeX](https://en.wikibooks.org/wiki/LaTeX/Installation#Distributions).
2.  Download the latest version of the Eisvogel template from [the release page](https://github.com/Wandmalfarbe/pandoc-latex-template/releases/latest).
3.  Extract the downloaded ZIP archive and open the folder.
4.  Move the template `eisvogel.tex` to your pandoc templates folder and rename the file to `eisvogel.latex`. The location of the templates folder depends on your operating system:
      - Unix, Linux, macOS: `/Users/USERNAME/.local/share/pandoc/templates/` or `/Users/USERNAME/.pandoc/templates/`
      - Windows Vista or later: `C:\Users\USERNAME\AppData\Roaming\pandoc\templates\`

    If there are no folders called `templates` or `pandoc` you need to create them and put the template `eisvogel.latex` inside. You can find the default user data directory on your system by looking at the output of `pandoc --version`.

## Usage

1.  Open the terminal and navigate to the folder where your markdown file is located.

2.  Execute the following command

    ``` bash
    pandoc example.md -o example.pdf --from markdown --template eisvogel --listings
    ```

    where `example.md` is the markdown file you want to convert to PDF.

In order to have nice headers and footers you need to supply metadata to your document. You can do that with a [YAML metadata block](http://pandoc.org/MANUAL.html#extension-yaml_metadata_block) at the top of your markdown document (see the [example markdown file](examples/basic-example/basic-example.md)). Your markdown document may look like the following:

``` markdown
---
title: "The Document Title"
author: [Example Author, Another Author]
date: "2017-02-20"
keywords: [Markdown, Example]
...

Here is the actual document text...
```

### Custom Template Variables

This template defines some new variables to control the appearance of the resulting PDF document. The existing template variables from pandoc are all supported and their documentation can be found in [the pandoc manual](https://pandoc.org/MANUAL.html#variables-for-latex).

  - `titlepage` (defaults to `false`)

    turns on the title page when `true`

  - `titlepage-color`

    the background color of the title page. The color value must be given as an HTML hex color like `D8DE2C` without the leading number sign (`#`). When specifying the color in YAML, it is advisable to enclose it in quotes like so `titlepage-color: "D8DE2C"` to avoid the truncation of the color (e.g. `000000` becoming `0`).

  - `titlepage-text-color` (defaults to `5F5F5F`)

    the text color of the title page

  - `titlepage-rule-color` (defaults to `435488`)

    the color of the rule on the top of the title page

  - `titlepage-rule-height` (defaults to `4`)

    the height of the rule on the top of the title page (in points)

  - `titlepage-background`

    the path to a background image for the title page. The background image is scaled to cover the entire page. In the examples folder under `titlepage-background` are a few example background images.

  - `caption-justification` (defaults to `raggedright`)

    justification setting for captions (uses the `justification` parameter of the [caption](https://ctan.org/pkg/caption?lang=en) package)

  - `toc-own-page` (defaults to `false`)

    begin new page after table of contents, when `true`

  - `listings-disable-line-numbers` (defaults to `false`)

    disables line numbers for all listings

  - `listings-no-page-break` (defaults to `false`)

    avoid page break inside listings

  - `disable-header-and-footer` (default to `false`)

    disables the header and footer completely on all pages

  - `header-left` (defaults to the title)

    the text on the left side of the header

  - `header-center`

    the text in the center of the header

  - `header-right` (defaults to the date)

    the text on the right side of the header

  - `footer-left` (defaults to the author)

    the text on the left side of the footer

  - `footer-center`

    the text in the center of the footer

  - `footer-right` (defaults to the page number)

    the text on the right side of the footer

  - `footnotes-pretty` (defaults to `false`)

    prettifies formatting of footnotes (requires package `footmisc`)

  - `footnotes-disable-backlinks` (defaults to `false`)

    disables making the reference from the footnote at the bottom of the page into a link back to the occurence of the footnote in the main text.

  - `book` (defaults to `false`)

    typeset as book

  - `logo`

    path to an image that will be displayed on the title page. The path is always relative to where pandoc is executed. The option `--resource-path` has no effect.

  - `logo-width` (defaults to `100`)

    the width of the logo (in points)

  - `first-chapter` (defaults to `1`)

    if typesetting a book with chapter numbers, specifies the number that will be assigned to the first chapter

  - `float-placement-figure` (defaults to `H`)

    Reset the default placement specifier for figure environments to the supplied value e.g. `htbp`. The available specifiers are listed below. The first four placement specifiers can be combined.

    1.  `h`: Place the float *here*, i.e., approximately at the same point it occurs in the source text.
    2.  `t`: Place the float at the *top* of the page.
    3.  `b`: Place the float at the *bottom* of the page.
    4.  `p`: Place the float on the next *page* that will contain only floats like figures and tables.
    5.  `H`: Place the float *HERE* (exactly where it occurs in the source text). The `H` specifier is provided by the [float package](https://ctan.org/pkg/float) and may not be used in conjunction with any other placement specifiers.

  - `table-use-row-colors` (defaults to `false`)

    enables row colors for tables. The default value is `false` because the coloring extends beyond the edge of the table and there is currently no way to change that.

  - `code-block-font-size` (defaults to `\small`)

    LaTeX command to change the font size for code blocks. The available values are `\tiny`, `\scriptsize`, `\footnotesize`, `\small`, `\normalsize`, `\large`, `\Large`, `\LARGE`, `\huge` and `\Huge`. This option will change the font size for default code blocks using the verbatim environment and for code blocks generated with listings.

## Examples

### Numbered Sections

For PDFs with [numbered sections](http://pandoc.org/MANUAL.html#options-affecting-specific-writers) use the `--number-sections` or `-N` option.

``` bash
pandoc example.md -o example.pdf --template eisvogel --number-sections
```

### Syntax Highlighting with Listings

You can get syntax highlighting of delimited code blocks by using the LaTeX package listings with the option `--listings`. This example will produce the same syntax highlighting as in the example PDF.

``` bash
pandoc example.md -o example.pdf --template eisvogel --listings
```

### Syntax Highlighting Without Listings

The following examples show [syntax highlighting of delimited code blocks](http://pandoc.org/MANUAL.html#syntax-highlighting) without using listings. To see a list of all the supported highlight styles, type `pandoc --list-highlight-styles`.

``` bash
pandoc example.md -o example.pdf --template eisvogel --highlight-style pygments
```

``` bash
pandoc example.md -o example.pdf --template eisvogel --highlight-style kate
```

``` bash
pandoc example.md -o example.pdf --template eisvogel --highlight-style espresso
```

``` bash
pandoc example.md -o example.pdf --template eisvogel --highlight-style tango
```

### Standalone LaTeX Document

To produce a standalone LaTeX document for compiling with any LaTeX editor use `.tex` as an output file extension.

``` bash
pandoc example.md -o example.tex --template eisvogel
```

### Changing the Document Language

The default language of this template is American English. The `lang` variable identifies the main language of the document, using a code according to [BCP 47](https://tools.ietf.org/html/bcp47) (e.g. `en` or `en-GB`). For an incomplete list of the supported language codes see [the documentation for the hyph-utf8 package (Section 2)](http://mirrors.ctan.org/language/hyph-utf8/doc/generic/hyph-utf8/hyph-utf8.pdf). The following example changes the language to British English:

``` bash
pandoc example.md -o example.pdf --template eisvogel -V lang=en-GB
```

The following example changes the language to German:

``` bash
pandoc example.md -o example.pdf --template eisvogel -V lang=de
```

### Typesetting a Book

To typeset a book supply the template variable `-V book` from the command line or via `book: true` in the metadata.

To get the correct chapter headings you need to tell pandoc that it should convert first level headings (indicated by one `#` in markdown) to chapters with the command line option `--top-level-division=chapter`. Chapter numbers start at 1. If you need to change that, specify `first-chapter` in the template variables.

There will be one blank page before each chapter because the template is two-sided per default. So if you plan to publish your book as a PDF and don’t need a blank page you should add the class option `onesided` which can be done by supplying a template variable `-V classoption=oneside`.

### Example Images

| A green title page | A background image on the title page |
| :----------------: | :----------------: |
| [![A green title page](examples/green-titlepage/green-titlepage.png)](examples/green-titlepage/green-titlepage.pdf) | [![A background image on the title page](examples/titlepage-background/titlepage-background.png)](examples/titlepage-background/titlepage-background.pdf) |

| images and tables | Code blocks styled without listings |
| :---------------: | :---------------: |
| [![images and tables](examples/images-and-tables/images-and-tables.png)](examples/images-and-tables/images-and-tables.pdf) | [![Code blocks styled without listings](examples/without-listings/without-listings.png)](examples/without-listings/without-listings.pdf) |

| A book | Code blocks styled with listings |
| :----: | :----: |
| [![A book](examples/book/book.png)](examples/book/book.pdf) | [![Code blocks styled with listings](examples/listings/listings.png)](examples/listings/listings.pdf) |

## Credits

  - This template includes code for styling block quotations from [pandoc-letter](https://github.com/aaronwolen/pandoc-letter) by [Aaron Wolen](https://github.com/aaronwolen).

## License

This project is open source licensed under the BSD 3-Clause License. Please see the [LICENSE file](LICENSE) for more information.
